@@ -5,9 +5,9 @@
 ;;
 ;; Author: Boris Buliga <boris@d12frosted.io>
 ;; Maintainer: Boris Buliga <boris@d12frosted.io>
-;; Package-Version: 20260118.1223
-;; Package-Revision: 2d3b5b473669
-;; Package-Requires: ((emacs "29.1") (vulpea "2.0.0") (vulpea-ui "0.1.0") (dash "2.20.0"))
+;; Package-Version: 20260205.1628
+;; Package-Revision: 002344eedfce
+;; Package-Requires: ((emacs "29.1") (vulpea "2.0.0") (vulpea-ui "1.0.0") (dash "2.20.0"))
 ;; Keywords: org-mode, roam, convenience
 ;; URL: https://github.com/d12frosted/vulpea-journal
 ;;
@@ -61,7 +61,8 @@
 
 (declare-function vulpea-journal-ui-setup "vulpea-journal-ui")
 
-(defvar vulpea-directory)
+(defvar vulpea-default-notes-directory)
+(defvar vulpea-db-sync-directories)
 
 
 ;;; Customization
@@ -81,7 +82,7 @@ Can be a plist or a function taking DATE and returning a plist.
 
 Required keys:
 - `:file-name' - strftime format for file path (relative to
-  `vulpea-directory')
+  `vulpea-default-notes-directory')
 - `:title' - strftime format for note title
 - `:tags' - List of tags (first tag identifies journal notes)
 
@@ -202,7 +203,8 @@ Falls back to CREATED property if file path doesn't contain a date."
          (file-fmt (plist-get tpl :file-name)))
     (expand-file-name
      (format-time-string file-fmt date)
-     vulpea-directory)))
+     (or vulpea-default-notes-directory
+         (car vulpea-db-sync-directories)))))
 
 (defun vulpea-journal--title-for-date (date)
   "Return title for journal note on DATE."
@@ -227,7 +229,17 @@ Returns time value or nil if date cannot be extracted."
   "Find existing journal note for DATE, or nil."
   (let ((file (vulpea-journal--file-for-date date)))
     (when (file-exists-p file)
-      (car (vulpea-db-query-by-file-path file 0)))))
+      (or (car (vulpea-db-query-by-file-path file 0))
+          ;; Fallback: try with resolved truename for symlink cases
+          ;; (e.g., macOS /var -> /private/var)
+          (let ((truename (file-truename file)))
+            (unless (string= truename file)
+              (car (vulpea-db-query-by-file-path truename 0))))
+          ;; Fallback: try with abbreviated path for databases that
+          ;; store paths with ~ instead of expanded home directory
+          (let ((abbreviated (abbreviate-file-name file)))
+            (unless (string= abbreviated file)
+              (car (vulpea-db-query-by-file-path abbreviated 0))))))))
 
 (defun vulpea-journal-note (date)
   "Get journal note for DATE, creating if needed."
